==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/DeviceManagementSettingCollectionConstraint.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;


/**
 * <i>“Constraint that enforces the maximum number of elements a collection”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "minimumLength", 
    "maximumLength"})
@JsonInclude(Include.NON_NULL)
public class DeviceManagementSettingCollectionConstraint extends DeviceManagementConstraint implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("minimumLength")
    protected Integer minimumLength;

    @JsonProperty("maximumLength")
    protected Integer maximumLength;

    protected DeviceManagementSettingCollectionConstraint() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.deviceManagementSettingCollectionConstraint";
    }

    /**
     * <i>“The minimum number of elements in the collection”</i>
     * 
     * @return property minimumLength
     */
    @Property(name="minimumLength")
    @JsonIgnore
    public Optional<Integer> getMinimumLength() {
        return Optional.ofNullable(minimumLength);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code minimumLength}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“The minimum number of elements in the collection”</i>
     * 
     * @param minimumLength
     *            new value of {@code minimumLength} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code minimumLength} field changed
     */
    public DeviceManagementSettingCollectionConstraint withMinimumLength(Integer minimumLength) {
        DeviceManagementSettingCollectionConstraint _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.deviceManagementSettingCollectionConstraint");
        _x.minimumLength = minimumLength;
        return _x;
    }

    /**
     * <i>“The maximum number of elements in the collection”</i>
     * 
     * @return property maximumLength
     */
    @Property(name="maximumLength")
    @JsonIgnore
    public Optional<Integer> getMaximumLength() {
        return Optional.ofNullable(maximumLength);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code maximumLength}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“The maximum number of elements in the collection”</i>
     * 
     * @param maximumLength
     *            new value of {@code maximumLength} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code maximumLength} field changed
     */
    public DeviceManagementSettingCollectionConstraint withMaximumLength(Integer maximumLength) {
        DeviceManagementSettingCollectionConstraint _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.deviceManagementSettingCollectionConstraint");
        _x.maximumLength = maximumLength;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderDeviceManagementSettingCollectionConstraint() {
        return new Builder();
    }

    public static final class Builder {
        private Integer minimumLength;
        private Integer maximumLength;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        /**
         * <i>“The minimum number of elements in the collection”</i>
         * 
         * @param minimumLength
         *            value of {@code minimumLength} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder minimumLength(Integer minimumLength) {
            this.minimumLength = minimumLength;
            this.changedFields = changedFields.add("minimumLength");
            return this;
        }

        /**
         * <i>“The maximum number of elements in the collection”</i>
         * 
         * @param maximumLength
         *            value of {@code maximumLength} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder maximumLength(Integer maximumLength) {
            this.maximumLength = maximumLength;
            this.changedFields = changedFields.add("maximumLength");
            return this;
        }

        public DeviceManagementSettingCollectionConstraint build() {
            DeviceManagementSettingCollectionConstraint _x = new DeviceManagementSettingCollectionConstraint();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.deviceManagementSettingCollectionConstraint";
            _x.minimumLength = minimumLength;
            _x.maximumLength = maximumLength;
            return _x;
        }
    }

    private DeviceManagementSettingCollectionConstraint _copy() {
        DeviceManagementSettingCollectionConstraint _x = new DeviceManagementSettingCollectionConstraint();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.minimumLength = minimumLength;
        _x.maximumLength = maximumLength;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("DeviceManagementSettingCollectionConstraint[");
        b.append("minimumLength=");
        b.append(this.minimumLength);
        b.append(", ");
        b.append("maximumLength=");
        b.append(this.maximumLength);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/DeviceManagementSettingCollectionConstraint.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;


/**
 * <i>“Constraint that enforces the maximum number of elements a collection”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "maximumLength", 
    "minimumLength"})
@JsonInclude(Include.NON_NULL)
public class DeviceManagementSettingCollectionConstraint extends DeviceManagementConstraint implements ODataType {

    @JsonProperty("maximumLength")
    protected Integer maximumLength;

    @JsonProperty("minimumLength")
    protected Integer minimumLength;

    protected DeviceManagementSettingCollectionConstraint() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.deviceManagementSettingCollectionConstraint";
    }

    /**
     * <i>“The maximum number of elements in the collection”</i>
     * 
     * @return property maximumLength
     */
    @Property(name="maximumLength")
    @JsonIgnore
    public Optional<Integer> getMaximumLength() {
        return Optional.ofNullable(maximumLength);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code maximumLength}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“The maximum number of elements in the collection”</i>
     * 
     * @param maximumLength
     *            new value of {@code maximumLength} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code maximumLength} field changed
     */
    public DeviceManagementSettingCollectionConstraint withMaximumLength(Integer maximumLength) {
        DeviceManagementSettingCollectionConstraint _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.deviceManagementSettingCollectionConstraint");
        _x.maximumLength = maximumLength;
        return _x;
    }

    /**
     * <i>“The minimum number of elements in the collection”</i>
     * 
     * @return property minimumLength
     */
    @Property(name="minimumLength")
    @JsonIgnore
    public Optional<Integer> getMinimumLength() {
        return Optional.ofNullable(minimumLength);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code minimumLength}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“The minimum number of elements in the collection”</i>
     * 
     * @param minimumLength
     *            new value of {@code minimumLength} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code minimumLength} field changed
     */
    public DeviceManagementSettingCollectionConstraint withMinimumLength(Integer minimumLength) {
        DeviceManagementSettingCollectionConstraint _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.deviceManagementSettingCollectionConstraint");
        _x.minimumLength = minimumLength;
        return _x;
    }

    public DeviceManagementSettingCollectionConstraint withUnmappedField(String name, Object value) {
        DeviceManagementSettingCollectionConstraint _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderDeviceManagementSettingCollectionConstraint() {
        return new Builder();
    }

    public static final class Builder {
        private Integer maximumLength;
        private Integer minimumLength;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        /**
         * <i>“The maximum number of elements in the collection”</i>
         * 
         * @param maximumLength
         *            value of {@code maximumLength} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder maximumLength(Integer maximumLength) {
            this.maximumLength = maximumLength;
            this.changedFields = changedFields.add("maximumLength");
            return this;
        }

        /**
         * <i>“The minimum number of elements in the collection”</i>
         * 
         * @param minimumLength
         *            value of {@code minimumLength} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder minimumLength(Integer minimumLength) {
            this.minimumLength = minimumLength;
            this.changedFields = changedFields.add("minimumLength");
            return this;
        }

        public DeviceManagementSettingCollectionConstraint build() {
            DeviceManagementSettingCollectionConstraint _x = new DeviceManagementSettingCollectionConstraint();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.deviceManagementSettingCollectionConstraint";
            _x.maximumLength = maximumLength;
            _x.minimumLength = minimumLength;
            return _x;
        }
    }

    private DeviceManagementSettingCollectionConstraint _copy() {
        DeviceManagementSettingCollectionConstraint _x = new DeviceManagementSettingCollectionConstraint();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.maximumLength = maximumLength;
        _x.minimumLength = minimumLength;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("DeviceManagementSettingCollectionConstraint[");
        b.append("maximumLength=");
        b.append(this.maximumLength);
        b.append(", ");
        b.append("minimumLength=");
        b.append(this.minimumLength);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
